@@ -1,5 +1,5 @@
 import fire
-from show_me.core import core, save_images, show_images
+from show_anything.core import core, save_images, show_images
 
 
 def save(
